module.exports = defineTest({
	description:
		'do not hang when scanning for line-breaks in ASI prevention and there are comment-like strings'
});
